Documentation
¶
Index ¶
- Variables
- func After(clk quartz.Clock, d time.Duration) <-chan time.Time
- func GetUnexportedField[T any](obj *T, fieldName string) any
- func OpenAPISchema[T ~string](r huma.Registry, enumName string, values []T) *huma.Schema
- func WaitFor(ctx context.Context, timeout WaitTimeout, condition func() (bool, error)) error
- type WaitTimeout
Constants ¶
This section is empty.
Variables ¶
var WaitTimedOut = xerrors.New("timeout waiting for condition")
Functions ¶
func After ¶ added in v0.12.0
After is a convenience function that returns a channel that will send the time after the given duration has elapsed using the provided clock. If clk is nil, a real clock will be used by default. Note that this function spawns a goroutine that will remain alive until the timer fires.
func GetUnexportedField ¶ added in v0.2.1
Based on https://stackoverflow.com/a/60598827
func OpenAPISchema ¶
based on https://github.com/danielgtaylor/huma/issues/621#issuecomment-2456588788
Types ¶
Click to show internal directories.
Click to hide internal directories.